Stan Math Library: stan/math/prim/mat/fun/tail.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
tail.hpp File Reference
`#include <stan/math/prim/mat/err/check_column_index.hpp>`
`#include <stan/math/prim/mat/err/check_row_index.hpp>`
`#include <stan/math/prim/mat/err/check_std_vector_index.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`
`#include <stan/math/prim/arr/meta/index_type.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, 1 > | stan::math::tail (const Eigen::Matrix< T, Eigen::Dynamic, 1 > &v, size_t n)
| Return the specified number of elements as a vector from the back of the specified vector. More...
template<typename T >
Eigen::Matrix< T, 1, Eigen::Dynamic > | stan::math::tail (const Eigen::Matrix< T, 1, Eigen::Dynamic > &rv, size_t n)
| Return the specified number of elements as a row vector from the back of the specified row vector. More...
template<typename T >
std::vector< T > | stan::math::tail (const std::vector< T > &sv, size_t n)

[ Stan Home Page ] © 2011–2016, Stan Development Team.